@@ -489,7 +489,7 @@ SC_CTOR(~A):
 ;;;
 (define (systemc output-filename)
   (let ((nets (schematic-nets toplevel-schematic))
-        (packages (schematic-packages toplevel-schematic))
+        (packages (schematic-package-names toplevel-schematic))
         ;; top level block name for the module
         (module-name (or (schematic-toplevel-attrib toplevel-schematic
                                                     'module_name)
