@@ -44,7 +44,9 @@
   #:use-module (netlist verbose)
   #:use-module ((netlist rename) #:select (get-rename-list))
 
-  #:export (main
+  #:export (lepton-netlist-version
+            main
+            set-toplevel-schematic!
             toplevel-schematic
             calling-flag?
             get-device
@@ -73,41 +75,38 @@
             gnetlist:wrap
             known?
             unknown?
-            pair<?)
+            pair<?
+            ;; Legacy variables
+            packages
+            all-unique-nets
+            all-nets
+            all-pins)
 
   #:re-export (source-library))
 
-;;; Create log file right away even if logging is enabled.
-(init-log "netlist")
 
-(match (lepton-version)
-  ((prepend-string dotted-version date-version git-commit)
-   (log! 'message
-         (_
-          "Lepton EDA/lepton-netlist version ~A~A.~A git: ~A
-")
-         prepend-string
-         dotted-version
-         date-version
-         (string-take git-commit 7)))
-  (_ #f))
+(define* (lepton-netlist-version #:optional output-to-log? exit?)
+  "Print lepton-netlist version, and copyright/warranty
+notices. If OUTPUT-TO-LOG? is requested, just output the version
+to log file, omitting copyright. Otherwise, output the full info
+to current standard output port and exit with exit status 0."
 
-;;; Print version info and exit.
-;;; Print gEDA version, and copyright/warranty notices, and exit with
-;;; exit status 0.
-(define (version)
-  (match (lepton-version)
-    ((prepend dotted date commit)
-     (format #t (_ "Lepton EDA ~A (git: ~A)
-Copyright (C) 1998-2016 gEDA developers
+  (define version-msg "Lepton EDA/lepton-netlist ~A~A.~A (git: ~A)\n")
+
+  (define copyright-msg (_ "Copyright (C) 1998-2016 gEDA developers
 Copyright (C) 2017-2018 Lepton EDA Contributors
 This is free software, and you are welcome to redistribute it under
 certain conditions. For details, see the file `COPYING', which is
 included in the Lepton EDA distribution.
-There is NO WARRANTY, to the extent permitted by law.
-")
-             dotted (string-take commit 7))))
-  (primitive-exit 0))
+There is NO WARRANTY, to the extent permitted by law.\n"))
+
+  (match (lepton-version)
+    ((prepend dotted date commit)
+     (if output-to-log?
+         (log! 'message version-msg prepend dotted date (string-take commit 7))
+         (begin
+           (format #t version-msg prepend dotted date (string-take commit 7))
+           (format #t copyright-msg))))))
 
 
 ;;----------------------------------------------------------------------
@@ -526,9 +525,9 @@ PACKAGE."
 (define (gnetlist:get-command-line)
   (string-join (command-line) " "))
 (define (gnetlist:get-packages level)
-  (schematic-packages toplevel-schematic))
+  (schematic-package-names toplevel-schematic))
 (define (gnetlist:get-non-unique-packages level)
-  (schematic-non-unique-packages toplevel-schematic))
+  (schematic-non-unique-package-names toplevel-schematic))
 (define (gnetlist:get-all-unique-nets level)
   (schematic-nets toplevel-schematic))
 (define (gnetlist:get-all-nets level)
@@ -868,7 +867,7 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
         (make-toplevel-schematic (map file->page files)
                                  netlist-mode))
   ;; Backward compatibility variables. Don't use them in your code!!!
-  (set! packages (schematic-packages toplevel-schematic))
+  (set! packages (schematic-package-names toplevel-schematic))
   (set! all-unique-nets (schematic-nets toplevel-schematic))
   (set! all-nets (schematic-non-unique-nets toplevel-schematic))
   (set! all-pins (map gnetlist:get-pins packages))
@@ -891,71 +890,168 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
         ;; output-filename is #f, output to stdout.
         (backend-proc output-filename))))
 
+
+
 ;;; Main program
 ;;;
-(define (main)
-  (let ((code-to-eval (gnetlist-option-ref 'eval-code)))
-    (when (not (null? code-to-eval))
-      (catch #t
-        (lambda () (apply eval-string code-to-eval))
-        catch-handler)))
+( define ( main )
+( let
+  (
+  ( output-filename   (get-output-filename) )
+  ( files             (gnetlist-option-ref '()) )            ; schematics
+  ( opt-backend       (gnetlist-option-ref 'backend) )       ; -g
+  ( opt-interactive   (gnetlist-option-ref 'interactive) )   ; -i
+  ( opt-verbose       (gnetlist-option-ref 'verbose) )       ; --verbose (-v)
+  ( opt-code-to-eval  (gnetlist-option-ref 'eval-code) )     ; -c
+  ( opt-help          (gnetlist-option-ref 'help) )          ; --help (-h)
+  ( opt-version       (gnetlist-option-ref 'version) )       ; --version (-V)
+  ( opt-list-backends (gnetlist-option-ref 'list-backends) ) ; --list-backends
+  ( opt-pre-load      (gnetlist-option-ref 'pre-load) )      ; -l
+  ( opt-post-load     (gnetlist-option-ref 'post-load) )     ; -m
+  ( netlist-mode      'geda )
+  ( backend-path      #f )
+  ( schematic         #f )
+  )
 
-  (when (gnetlist-option-ref 'help)
-    (usage))
+  ; local functions:
 
-  (when (gnetlist-option-ref 'version)
-    (version))
+  ( define ( error-no-backend )
+    (netlist-error 1 (_ "You gave neither backend to execute nor interactive mode!\n"))
+  )
 
-  ((@@ (guile-user) parse-rc) "lepton-netlist" "gnetlistrc")
-  (if (gnetlist-option-ref 'list-backends)
-      (gnetlist-backends)
-      (let ((files (gnetlist-option-ref '())))
-        (if (null? files)
-            (netlist-error 1
-                           (_ "No schematic files specified for processing.
-Run `~A --help' for more information.
-")
-                           (car (program-arguments)))
-            (let* ((backend (gnetlist-option-ref 'backend))
-                   ;; this is a kludge to make sure that spice mode gets set
-                   (netlist-mode (if (and backend (string-prefix? "spice" backend))
-                                     'spice
-                                     'geda))
+  ( define ( error-no-sch )
+    (netlist-error 1 (_ "No schematic files specified for processing.\n~
+                         Run `~A --help' for more information.\n")
+                     (car (program-arguments)))
+  )
 
-                   ;; Search for backend scm file in load path
-                   (backend-path (and backend
-                                      (%search-load-path (format #f
-                                                                 "gnet-~A.scm"
-                                                                 backend))))
-                   (output-filename (get-output-filename))
-                   (interactive-mode? (gnetlist-option-ref 'interactive))
-                   (verbose-mode? (gnetlist-option-ref 'verbose)))
+  ( define ( error-backend-not-found backend )
+    (netlist-error 1 (_ "Could not find backend `~A' in load path.\n~
+                         Run `~A --list-backends' for a full list of available backends.\n")
+                     backend (car (program-arguments)))
+  )
 
-              ;; Evaluate the first set of Scheme expressions.
-              (for-each primitive-load (gnetlist-option-ref 'pre-load))
-              ;; Load backend.
-              (when backend-path (primitive-load backend-path))
-              ;; Evaluate second set of Scheme expressions.
-              (for-each primitive-load (gnetlist-option-ref 'post-load))
 
-              (when verbose-mode? (print-gnetlist-config))
+  ; Parse configuration:
+  ;
+  ( (@@ (guile-user) parse-rc) "lepton-netlist" "gnetlistrc" )
 
-              (if (or backend interactive-mode?)
-                  ;; Load backend code.
-                  (let ((schematic (set-toplevel-schematic! files netlist-mode)))
-                    (verbose-print-netlist (schematic-netlist schematic))
-                    (if interactive-mode?
-                        (lepton-repl)
-                        (if backend-path
-                            (run-backend backend output-filename)
-                            ;; If the backend couldn't be found, fail.
-                            (netlist-error 1
-                                           (_ "Could not find backend `~A' in load path.
+  ; This is a kludge to make sure that spice mode gets set:
+  ;
+  ( when ( and opt-backend (string-prefix? "spice" opt-backend) )
+    ( set! netlist-mode 'spice )
+  )
+
+  ; Evaluate Scheme expression at startup (-c EXPR):
+  ;
+  ( unless ( null? opt-code-to-eval )
+    ( catch #t
+      ( lambda()
+        ( apply eval-string opt-code-to-eval )
+      )
+      ( lambda( tag . args )
+        ( catch-handler tag args )
+        ( netlist-error 1 (_ "Failed to evaluate Scheme expression at startup.\n") )
+      )
+    )
+  )
+
+  ( when opt-help
+    ( usage )
+  )
+
+  ( when opt-version
+    ( lepton-netlist-version )
+    ( primitive-exit 0 )
+  )
+
+  ( when opt-list-backends
+    ( gnetlist-backends )
+    ( primitive-exit 0 )
+  )
+
+  ; Check input schematics:
+  ;
+  ( when ( and (null? files) (not opt-interactive) )
+    ( error-no-sch )
+  )
+
+
+  ; Load Scheme FILE before loading backend (-l FILE):
+  ;
+  ( catch #t
+    ( lambda()
+      ( for-each primitive-load opt-pre-load )
+    )
+    ( lambda( tag . args )
+      ( catch-handler tag args )
+      ( netlist-error 1 (_ "Failed to load Scheme file before loading backend.\n") )
+    )
+  )
+
+  ; Load backend:
+  ;
+  ( when opt-backend
+    ( set! backend-path ( %search-load-path (format #f "gnet-~A.scm" opt-backend) ) )
+  )
+
+  ( when backend-path
+    ( catch #t
+      ( lambda()
+        ( primitive-load backend-path )
+      )
+      ( lambda( tag . args )
+        ( catch-handler tag args )
+        ( netlist-error 1 (_ "Failed to load backend file.\n") )
+      )
+    )
+  )
+
+  ; Load Scheme FILE after loading backend (-m FILE):
+  ;
+  ( catch #t
+    ( lambda()
+      ( for-each primitive-load opt-post-load )
+    )
+    ( lambda( tag . args )
+      ( catch-handler tag args )
+      ( netlist-error 1 (_ "Failed to load Scheme file after loading backend.\n") )
+    )
+  )
+
+  ; Verbose mode (-v): print configuration:
+  ;
+  ( when opt-verbose
+    ( print-gnetlist-config )
+  )
+
+  ; Neither backend (-g), nor interactive mode (-i) specified:
+  ;
+  ( unless ( or opt-backend opt-interactive )
+    ( error-no-backend )
+  )
+
+  ; This sets [toplevel-schematic] global variable:
+  ;
+  ( set! schematic (set-toplevel-schematic! files netlist-mode) )
+
+  ; Verbose mode (-v): print internal netlist representation:
+  ;
+  ( when opt-verbose
+    ( verbose-print-netlist (schematic-netlist schematic) )
+  )
+
+
+  ; Do actual work:
+  ;
+  ( if opt-interactive
+    ( lepton-repl )   ; if
+    ( if backend-path ; else
+      ( run-backend opt-backend output-filename ) ; if
+      ( error-backend-not-found opt-backend )     ; else
+    )
+  )
+
+) ; let
+) ; main()
 
-Run `~A --list-backends' for a full list of available backends.
-")
-                                           backend
-                                           (car (program-arguments))))))
-                  ;; No backend given on the command line.
-                  (netlist-error 1
-                                 (_ "You gave neither backend to execute nor interactive mode!\n"))))))))
