@@ -57,14 +57,11 @@ SCM g_keys_edit_delete(SCM rest);
 SCM g_keys_edit_rotate_90(SCM rest);
 SCM g_keys_edit_mirror(SCM rest);
 SCM g_keys_edit_slot(SCM rest);
-SCM g_keys_edit_color(SCM rest);
+SCM g_keys_edit_object_properties(SCM rest);
 SCM g_keys_edit_edit(SCM rest);
-SCM g_keys_edit_pin_type(SCM rest);
 SCM g_keys_edit_text(SCM rest);
 SCM g_keys_edit_lock(SCM rest);
 SCM g_keys_edit_unlock(SCM rest);
-SCM g_keys_edit_linetype(SCM rest);
-SCM g_keys_edit_filltype(SCM rest);
 SCM g_keys_edit_translate(SCM rest);
 SCM g_keys_edit_invoke_macro(SCM rest);
 SCM g_keys_edit_embed(SCM rest);
@@ -141,7 +138,6 @@ SCM g_keys_attributes_show_value(SCM rest);
 SCM g_keys_attributes_show_both(SCM rest);
 SCM g_keys_attributes_visibility_toggle(SCM rest);
 SCM g_keys_script_console(SCM rest);
-SCM g_keys_options_text_size(SCM rest);
 SCM g_keys_options_afeedback(SCM rest);
 SCM g_keys_options_grid(SCM rest);
 SCM g_keys_options_snap(SCM rest);
@@ -279,10 +275,9 @@ void i_callback_edit_mcopy(gpointer data, guint callback_action, GtkWidget *widg
 void i_callback_edit_move(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_delete(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_edit(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_edit_pin_type(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_text(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_slot(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_edit_color(gpointer data, guint callback_action, GtkWidget *widget);
+void i_callback_edit_object_properties(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_rotate_90(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_mirror(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_lock(gpointer data, guint callback_action, GtkWidget *widget);
@@ -297,8 +292,6 @@ void i_callback_edit_find(gpointer data, guint callback_action, GtkWidget *widge
 void i_callback_edit_hide_text(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_show_text(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_edit_autonumber_text(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_edit_linetype(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_edit_filltype(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_view_sidebar(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_view_status(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_view_find_text_state(gpointer data, guint callback_action, GtkWidget *widget);
@@ -369,7 +362,6 @@ void i_callback_attributes_show_value(gpointer data, guint callback_action, GtkW
 void i_callback_attributes_show_both(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_attributes_visibility_toggle(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_script_console(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_options_text_size(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_options_snap_size(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_options_scale_up_snap_size(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_options_scale_down_snap_size(gpointer data, guint callback_action, GtkWidget *widget);
@@ -637,7 +629,6 @@ int text_view_calculate_real_tab_width(GtkTextView *textview, int tab_size);
 void select_all_text_in_textview(GtkTextView *textview);
 void text_input_dialog(GschemToplevel *w_current);
 void text_edit_dialog(GschemToplevel *w_current);
-void line_type_dialog(GschemToplevel *w_current);
 void arc_angle_dialog(GschemToplevel *w_current, OBJECT *arc_object);
 void snap_size_dialog(GschemToplevel *w_current);
 void slot_edit_dialog(GschemToplevel *w_current, const char *count, const char *string);
@@ -659,7 +650,6 @@ void major_changed_dialog(GschemToplevel* w_current);
 gboolean x_dialog_close_changed_page (GschemToplevel *w_current, PAGE *page);
 gboolean x_dialog_close_window (GschemToplevel *w_current);
 int x_dialog_validate_attribute(GtkWindow* parent, char *attribute);
-void x_dialog_edit_pin_type(GschemToplevel *w_current, const GList *obj_list);
 /* x_event.c */
 gint x_event_expose(GschemPageView *widget, GdkEventExpose *event, GschemToplevel *w_current);
 gint x_event_raise_dialog_boxes (GschemPageView *view, GdkEventExpose *event, GschemToplevel *w_current);
