@@ -957,18 +957,16 @@
 (global-set-key "E R" '&edit-rotate-90)
 (global-set-key "E I" '&edit-mirror)
 (global-set-key "E <Shift>S" '&edit-slot)
-(global-set-key "E O" '&edit-color)
 (global-set-key "E L" '&edit-lock)
 (global-set-key "E <Shift>L" '&edit-unlock)
-(global-set-key "E W" '&edit-linetype)
-(global-set-key "E F" '&edit-filltype)
-(global-set-key "E P" '&edit-pin-type)
 (global-set-key "E T" '&edit-translate)
 (global-set-key "E <Shift>colon" '&edit-invoke-macro)
+(global-set-key "E O" '&edit-object-properties )
 (global-set-key "E B" '&edit-embed)
 (global-set-key "E <Shift>B" '&edit-unembed)
 (global-set-key "E U" '&edit-update)
 (global-set-key "E N" '&edit-show-hidden)
+(global-set-key "T I" '&edit-show-hidden)
 
 (global-set-key "F W" '&file-new-window)
 (global-set-key "F N" '&file-new)
@@ -996,22 +994,22 @@
 (global-set-key "<Shift>H D" '&hierarchy-down-schematic)
 (global-set-key "<Shift>H S" '&hierarchy-down-symbol)
 (global-set-key "<Shift>H U" '&hierarchy-up)
-(global-set-key "<Shift>H O" '&hierarchy-documentation)
+(global-set-key "H O" '&hierarchy-documentation)
 
 (global-set-key "I" '&add-component)
 (global-set-key "L" '&add-line)
 (global-set-key "M" '&edit-move)
 (global-set-key "N" '&add-net)
 
-(global-set-key "O T" '&options-text-size)
 (global-set-key "O A" '&options-action-feedback)
 (global-set-key "O G" '&options-grid)
 (global-set-key "O S" '&options-snap)
 (global-set-key "O R" '&options-rubberband)
 (global-set-key "O M" '&options-magneticnet)
-(global-set-key "O <Shift>S" '&options-snap-size)
+(global-set-key "O O" '&options-snap-size)
 (global-set-key "O L" '&options-show-log-window)
 (global-set-key "O C" '&options-show-coord-window)
+(global-set-key "O F" '&options-select-font)
 
 (global-set-key "P M" '&page-manager)
 (global-set-key "P N" '&page-next)
@@ -1031,7 +1029,7 @@
 (global-set-key "T V" '&attributes-show-value)
 (global-set-key "T B" '&attributes-show-both)
 (global-set-key "T T" '&attributes-visibility-toggle)
-(global-set-key "T <Shift>F" '&edit-find-text)
+(global-set-key "T F" '&edit-find-text)
 (global-set-key "T H" '&edit-hide-text)
 (global-set-key "T <Shift>H" '&edit-show-text)
 (global-set-key "T U" '&edit-autonumber)
@@ -1115,14 +1113,14 @@
            (,(N_ "_Save")             &file-save              "gtk-save")
            (,(N_ "Save _As...")       &file-save-as           "gtk-save-as")
            (,(N_ "Save All")          &file-save-all          "gtk-save")
-           (,(N_ "_Revert")           &page-revert            "gtk-revert-to-saved")
-           ("SEPARATOR"               #f                      #f                      #f)
+           ("SEPARATOR"               #f                      #f)
            (,(N_ "_Print...")         &file-print             "gtk-print")
-           (,(N_ "Write _image...")   &file-image             #f)
-           ("SEPARATOR"               #f                      #f                      #f)
+           (,(N_ "Write _Image...")   &file-image             #f)
+           ("SEPARATOR"               #f                      #f)
+           (,(N_ "Invoke Macro...")   &edit-invoke-macro      "gtk-execute")
            (,(N_ "Execute Script...") &file-script            "gtk-execute")
            (,(N_ "REPL...")           &file-repl              "gtk-execute")
-           ("SEPARATOR"               #f                      #f                      #f)
+           ("SEPARATOR"               #f                      #f)
            (,(N_ "New Window")        &file-new-window        "window-new")
            (,(N_ "_Close Window")     &file-close-window      "gtk-close")
            (,(N_ "_Quit")             &file-quit              "gtk-quit")))
@@ -1148,22 +1146,18 @@
            (,(N_ "Rotate 90 Mode")     &edit-rotate-90        "object-rotate-left")
            (,(N_ "Mirror Mode")        &edit-mirror           "object-flip-horizontal")
            ("SEPARATOR"                #f                     #f)
+           (,(N_ "Object Properties...") &edit-object-properties "gtk-properties")
            (,(N_ "Edit...")            &edit-edit             #f)
            (,(N_ "Edit Text...")       &edit-text             "gtk-edit")
            (,(N_ "Slot...")            &edit-slot             #f)
-           (,(N_ "Color...")           &edit-color            "gtk-select-color")
-           (,(N_ "Line Width & Type...") &edit-linetype       #f)
-           (,(N_ "Fill Type...")         &edit-filltype       #f)
-           (,(N_ "Pin Type...")        &edit-pin-type         #f)
-           (,(N_ "Symbol Translate...")  &edit-translate      #f)
+           ("SEPARATOR"                #f                     #f)
            (,(N_ "Lock")               &edit-lock             #f)
            (,(N_ "Unlock")             &edit-unlock           #f)
            ("SEPARATOR"                #f                     #f)
-           (,(N_ "Invoke Macro")         &edit-invoke-macro   #f)
            (,(N_ "Embed Component/Picture")    &edit-embed    #f)
            (,(N_ "Unembed Component/Picture")  &edit-unembed  #f)
            (,(N_ "Update Component")   &edit-update           "gtk-refresh")
-           (,(N_ "Show/Hide Inv Text") &edit-show-hidden      #f)))
+           (,(N_ "Symbol Translate...")  &edit-translate      #f)))
 
 (define buffer-menu-items
 ;;
@@ -1189,10 +1183,10 @@
 ;;
 ;;          menu item name        menu action             menu stock icon
 ;;
-        `( (,(N_ "Sidebar")             &view-sidebar           #f)
-           (,(N_ "Status")              &view-status            #f)
+        `( (,(N_ "Side Dock")           &view-sidebar           #f)
+           (,(N_ "Bottom Dock")         &view-status            #f)
            ("SEPARATOR"                 #f                      #f)
-           (,(N_ "Find Text State")     &view-find-text-state   #f)
+           (,(N_ "Find Text Results")   &view-find-text-state   #f)
            ("SEPARATOR"                 #f                      #f)
            (,(N_ "_Redraw")             &view-redraw            "gtk-refresh")
            (,(N_ "_Pan")                &view-pan               #f)
@@ -1202,11 +1196,11 @@
            (,(N_ "Zoom _Out")           &view-zoom-out          "gtk-zoom-out")
            (,(N_ "Zoom _Full")          &view-zoom-full         #f)
            ("SEPARATOR"                 #f                      #f)
-           (,(N_ "_Dark color scheme")  &view-dark-colors       #f)
-           (,(N_ "_Light color scheme") &view-light-colors      #f)
-           (,(N_ "B_W color scheme")    &view-bw-colors         #f)
+           (,(N_ "_Dark Color Scheme")  &view-dark-colors       #f)
+           (,(N_ "_Light Color Scheme") &view-light-colors      #f)
+           (,(N_ "B_W Color Scheme")    &view-bw-colors         #f)
            ("SEPARATOR"                 #f                      #f)
-           (,(N_ "Color scheme editor...") &view-color-edit     #f)
+           (,(N_ "Color Scheme Editor...") &view-color-edit     #f)
          ))
 
 (define page-menu-items
@@ -1214,11 +1208,13 @@
 ;;          menu item name      menu action             menu stock icon
 ;;
         `( (,(N_ "_Manager...")       &page-manager           #f)
+           ("SEPARATOR"               #f                      #f)
            (,(N_ "_Previous")         &page-prev              "gtk-go-back")
            (,(N_ "_Next")             &page-next              "gtk-go-forward")
-           (,(N_ "_Revert")           &page-revert            "gtk-revert-to-saved")
            (,(N_ "_Close")            &page-close             "gtk-close")
            ("SEPARATOR"               #f                      #f)
+           (,(N_ "_Revert...")        &page-revert            "gtk-revert-to-saved")
+           ("SEPARATOR"               #f                      #f)
            (,(N_ "Next Tab")          &page-next-tab          "gtk-go-forward")
            (,(N_ "Previous Tab")      &page-prev-tab          "gtk-go-back")
         )
@@ -1229,27 +1225,30 @@
 ;;          menu item name      menu action             menu stock icon
 ;;
         `( (,(N_ "_Component...")     &add-component   "insert-symbol")
+           ("SEPARATOR"              #f                #f)
            (,(N_ "_Net")              &add-net         "insert-net")
            (,(N_ "B_us")              &add-bus         "insert-bus")
+           ("SEPARATOR"              #f                #f)
            (,(N_ "_Attribute...")     &add-attribute   "insert-attribute")
            (,(N_ "_Text...")          &add-text        "insert-text")
-           ("SEPARATOR"              #f)
+           ("SEPARATOR"              #f                #f)
            (,(N_ "_Line")             &add-line        "insert-line")
            (,(N_ "Pat_h")             &add-path        "insert-path")
            (,(N_ "_Box")              &add-box         "insert-box")
            (,(N_ "C_ircle")           &add-circle      "insert-circle")
            (,(N_ "A_rc")              &add-arc         "insert-arc")
            (,(N_ "_Pin")              &add-pin         "insert-pin")
+           ("SEPARATOR"              #f                #f)
            (,(N_ "Pictu_re...")       &add-picture     "insert-image")))
 
 (define hierarchy-menu-items
 ;;
 ;;          menu item name      menu action               menu stock icon
 ;;
-        `( (,(N_ "_Down Schematic")   &hierarchy-down-schematic "gtk-go-down")
-           (,(N_ "Down _Symbol")      &hierarchy-down-symbol    "gtk-goto-bottom")
-           (,(N_ "_Up")               &hierarchy-up             "gtk-go-up")
-           (,(N_ "D_ocumentation...") &hierarchy-documentation  "symbol-datasheet")))
+        `( (,(N_ "_Up")               &hierarchy-up             "gtk-go-up")
+           ("SEPARATOR"              #f                #f)
+           (,(N_ "_Down Schematic")   &hierarchy-down-schematic "gtk-go-down")
+           (,(N_ "Down _Symbol")      &hierarchy-down-symbol    "gtk-goto-bottom")))
 
 (define attributes-menu-items
 ;;
@@ -1257,45 +1256,53 @@
 ;;
         `( (,(N_ "_Attach")           &attributes-attach      "attribute-attach")
            (,(N_ "_Detach")           &attributes-detach      "attribute-detach")
+           ("SEPARATOR" #f #f)
            (,(N_ "Show _Value")       &attributes-show-value  "attribute-show-value")
            (,(N_ "Show _Name")        &attributes-show-name   "attribute-show-name")
            (,(N_ "Show _Both")        &attributes-show-both   "attribute-show-both")
            (,(N_ "_Toggle Visibility")  &attributes-visibility-toggle   #f)
-           (,(N_ "_Find Specific Text...")  &edit-find-text   "gtk-find")
-           (,(N_ "_Hide Specific Text...")  &edit-hide-text   #f)
-           (,(N_ "_Show Specific Text...")  &edit-show-text   #f)
-           (,(N_ "A_utonumber Text...")     &edit-autonumber  #f)))
+           ("SEPARATOR" #f #f)
+           (,(N_ "_Hide Specific Text...") &edit-hide-text   #f)
+           (,(N_ "_Show Specific Text...") &edit-show-text   #f)
+           (,(N_ "Show/Hide Hidden Text")  &edit-show-hidden #f)
+           ("SEPARATOR" #f #f)
+           (,(N_ "_Find Text/Check Symbol...") &edit-find-text   "gtk-find")
+           (,(N_ "A_utonumber Text...")        &edit-autonumber  #f)))
 
 (define options-menu-items
 ;;
 ;;          menu item name      menu action             menu stock icon
 ;;
-        `( (,(N_ "_Font...")                 &options-select-font)
-           (,(N_ "Text Size...")             &options-text-size)
-           (,(N_ "Cycle _grid styles")       &options-grid)
-           (,(N_ "Toggle _Snap On/Off")      &options-snap)
-           (,(N_ "Snap Grid S_pacing...")    &options-snap-size)
-           (,(N_ "Scale _up Grid Spacing")   &options-scale-up-snap-size)
-           (,(N_ "Scale _down Grid Spacing") &options-scale-down-snap-size)
-           (,(N_ "Toggle _Outline/Box")      &options-action-feedback)
-           (,(N_ "Toggle Net _Rubberband")   &options-rubberband)
-           (,(N_ "Toggle _Magnetic Net")     &options-magneticnet)
-           (,(N_ "Show _Log Window...")      &options-show-log-window)
-           (,(N_ "Show _Coord Window...")    &options-show-coord-window)))
+        `( (,(N_ "_Options...") &options-snap-size)
+           (,(N_ "_Font...")    &options-select-font)
+           ("SEPARATOR" #f #f)
+           (,(N_ "Grid +")      &options-scale-up-snap-size)
+           (,(N_ "Grid -")      &options-scale-down-snap-size)
+           ("SEPARATOR" #f #f)
+           (,(N_ "Grid Style: Cycle Dots/Mesh/Off")  &options-grid)
+           (,(N_ "Grid Snap: Cycle Grid/Resnap/Off") &options-snap)
+           ("SEPARATOR" #f #f)
+           (,(N_ "Feedback Mode: Outline/Box") &options-action-feedback)
+           (,(N_ "Net: Rubberband On/Off")     &options-rubberband)
+           (,(N_ "Net: Magnetic On/Off")       &options-magneticnet)
+           ("SEPARATOR" #f #f)
+           (,(N_ "_Coord Window") &options-show-coord-window)
+           (,(N_ "_Log Window")   &options-show-log-window)))
 
 (define help-menu-items
 ;;
 ;;          menu item name                menu action               menu stock icon
 ;;
         `(
-           (,(N_ "gschem User _Guide...")  &help-guide                "gtk-help")
-           (,(N_ "gschem _FAQ...")         &help-faq                  "help-faq")
-           (,(N_ "gEDA Docu_mentation...") &help-manual               "help-browser")
-           (,(N_ "gEDA _Wiki...")          &help-wiki                 "web-browser")
-           (,(N_ "Component D_ocumentation...") &hierarchy-documentation   "symbol-datasheet")
-           ("SEPARATOR"                   #f                        #f)
+           (,(N_ "User _Guide")  &help-guide                "gtk-help")
+           (,(N_ "_FAQ")         &help-faq                  "help-faq")
+           (,(N_ "Docu_mentation") &help-manual               "help-browser")
+           (,(N_ "_Wiki")          &help-wiki                 "web-browser")
+           ("SEPARATOR"                   #f                          #f)
+           (,(N_ "Find Component D_ocumentation") &hierarchy-documentation "symbol-datasheet")
+           ("SEPARATOR"                   #f                          #f)
            (,(N_ "_Hotkeys...")            &help-hotkeys              "preferences-desktop-keyboard-shortcuts")
-           (,(N_ "_About...")              &help-about                "gtk-about")))
+           (,(N_ "_About")              &help-about                "gtk-about")))
 
 ;
 ; Now actually add the menus.  The order here defines the order in which
