@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2013 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2015 gEDA Contributors
+ * Copyright (C) 2017-2018 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,14 +88,11 @@ DEFINE_G_KEYS(edit_delete)
 DEFINE_G_KEYS(edit_rotate_90)
 DEFINE_G_KEYS(edit_mirror)
 DEFINE_G_KEYS(edit_slot)
-DEFINE_G_KEYS(edit_color)
+DEFINE_G_KEYS(edit_object_properties)
 DEFINE_G_KEYS(edit_edit)
-DEFINE_G_KEYS(edit_pin_type)
 DEFINE_G_KEYS(edit_text)
 DEFINE_G_KEYS(edit_lock)
 DEFINE_G_KEYS(edit_unlock)
-DEFINE_G_KEYS(edit_linetype)
-DEFINE_G_KEYS(edit_filltype)
 DEFINE_G_KEYS(edit_translate)
 DEFINE_G_KEYS(edit_invoke_macro)
 DEFINE_G_KEYS(edit_embed)
@@ -184,10 +182,6 @@ DEFINE_G_KEYS(attributes_visibility_toggle)
 /* i_callback_script_console is not currently implemented */
 DEFINE_G_KEYS(script_console)
 
-/* repeat last command doesn't make sense on options either??? (does
- * it?) */
-DEFINE_G_KEYS(options_text_size)
-
 /* repeat last command doesn't make sense on options either??? (does
  * it?) */
 DEFINE_G_KEYS(options_afeedback)
