@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2011 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2015 gEDA Contributors
+ * Copyright (C) 2017-2018 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -144,14 +145,11 @@ static struct gsubr_t gschem_funcs[] = {
   { "edit-rotate-90",               0, 0, 0, (SCM (*) ()) g_keys_edit_rotate_90 },
   { "edit-mirror",                  0, 0, 0, (SCM (*) ()) g_keys_edit_mirror },
   { "edit-slot",                    0, 0, 0, (SCM (*) ()) g_keys_edit_slot },
-  { "edit-color",                   0, 0, 0, (SCM (*) ()) g_keys_edit_color },
+  { "edit-object-properties",       0, 0, 0, (SCM (*) ()) g_keys_edit_object_properties },
   { "edit-edit",                    0, 0, 0, (SCM (*) ()) g_keys_edit_edit },
   { "edit-text",                    0, 0, 0, (SCM (*) ()) g_keys_edit_text },
   { "edit-lock",                    0, 0, 0, (SCM (*) ()) g_keys_edit_lock },
   { "edit-unlock",                  0, 0, 0, (SCM (*) ()) g_keys_edit_unlock },
-  { "edit-linetype",                0, 0, 0, (SCM (*) ()) g_keys_edit_linetype },
-  { "edit-filltype",                0, 0, 0, (SCM (*) ()) g_keys_edit_filltype },
-  { "edit-pin-type",                0, 0, 0, (SCM (*) ()) g_keys_edit_pin_type },
   { "edit-translate",               0, 0, 0, (SCM (*) ()) g_keys_edit_translate },
   { "edit-invoke-macro",            0, 0, 0, (SCM (*) ()) g_keys_edit_invoke_macro },
   { "edit-embed",                   0, 0, 0, (SCM (*) ()) g_keys_edit_embed },
@@ -230,7 +228,6 @@ static struct gsubr_t gschem_funcs[] = {
   { "attributes-show-value",        0, 0, 0, (SCM (*) ()) g_keys_attributes_show_value },
   { "attributes-show-both",         0, 0, 0, (SCM (*) ()) g_keys_attributes_show_both },
   { "attributes-visibility-toggle", 0, 0, 0, (SCM (*) ()) g_keys_attributes_visibility_toggle },
-  { "options-text-size",            0, 0, 0, (SCM (*) ()) g_keys_options_text_size },
   { "options-snap-size",            0, 0, 0, (SCM (*) ()) g_keys_options_snap_size },
   { "options-scale-up-snap-size",   0, 0, 0, (SCM (*) ()) g_keys_options_scale_up_snap_size },
   { "options-scale-down-snap-size", 0, 0, 0, (SCM (*) ()) g_keys_options_scale_down_snap_size },
