@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2015 gEDA Contributors
+ * Copyright (C) 2017-2018 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -117,34 +118,6 @@ gschem_object_properties_widget_new (GschemToplevel *w_current)
 
 
 
-/*! \brief Open the dialog box to edit fill properties
- *
- *  \par Function Description
- *  This function creates or raises the modal text entry dialog
- *
- *  \param [in] w_current The gschem toplevel
- */
-void
-line_type_dialog (GschemToplevel *w_current)
-{
-  x_widgets_show_object_properties (w_current);
-}
-
-
-
-/*! \brief Open the dialog box to edit pin type
- *
- *  \param [in] w_current The gschem toplevel
- *  \param [in] obj_list unused
- */
-void
-x_dialog_edit_pin_type (GschemToplevel *w_current, const GList *obj_list)
-{
-  x_widgets_show_object_properties (w_current);
-}
-
-
-
 /*! \private
  *  \brief Initialize GschemObjectPropertiesWidget class
  *
