@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2011 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2018 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -603,24 +604,6 @@ DEFINE_I_CALLBACK(edit_edit)
   o_edit(w_current, geda_list_get_glist( gschem_toplevel_get_toplevel (w_current)->page_current->selection_list ) );
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-DEFINE_I_CALLBACK(edit_pin_type)
-{
-  GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-
-  g_return_if_fail (w_current != NULL);
-
-  i_update_middle_button (w_current, i_callback_edit_pin_type, _("Edit pin type"));
-
-  x_dialog_edit_pin_type (w_current,
-                          geda_list_get_glist (gschem_toplevel_get_toplevel (w_current)->
-                                                 page_current->selection_list));
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -657,21 +640,16 @@ DEFINE_I_CALLBACK(edit_slot)
   }
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
+/*! \brief Show "object properties" widget
  *
  */
-DEFINE_I_CALLBACK(edit_color)
+DEFINE_I_CALLBACK(edit_object_properties)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
 
   g_return_if_fail (w_current != NULL);
 
-  i_update_middle_button(w_current, i_callback_edit_color, _("Color"));
-
-  /* dialogs have been merged */
-  line_type_dialog(w_current);
+  x_widgets_show_object_properties (w_current);
 }
 
 /*! \todo Finish function documentation!!!
@@ -1071,36 +1049,6 @@ DEFINE_I_CALLBACK(edit_autonumber_text)
   autonumber_text_dialog(w_current);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-DEFINE_I_CALLBACK(edit_linetype)
-{
-  GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-
-  g_return_if_fail (w_current != NULL);
-
-  /* dialogs have been merged */
-  line_type_dialog(w_current);
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-DEFINE_I_CALLBACK(edit_filltype)
-{
-  GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-
-  g_return_if_fail (w_current != NULL);
-
-  /* dialogs have been merged */
-  line_type_dialog(w_current);
-}
-
 /*! \section view-menu View Menu Callback Functions */
 /*! \brief Toggle the visibility of the sidebar
  */
@@ -1132,7 +1080,6 @@ DEFINE_I_CALLBACK(view_status)
  */
 DEFINE_I_CALLBACK(view_find_text_state)
 {
-  gboolean visible;
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
 
   g_return_if_fail (w_current != NULL);
@@ -2260,7 +2207,7 @@ DEFINE_I_CALLBACK(hierarchy_down_schematic)
         const char *msg = (err != NULL) ? err->message : "Unknown error.";
         char *secondary =
           g_strdup_printf (_("Failed to descend hierarchy into '%1$s': %2$s\n\n"
-                             "The gschem log may contain more information."),
+                             "The lepton-schematic log may contain more information."),
                            current_filename, msg);
 
         s_log_message(_("Failed to descend into '%1$s': %2$s"),
@@ -2682,24 +2629,6 @@ DEFINE_I_CALLBACK(script_console)
   printf(_("Sorry but this is a non-functioning menu option\n"));
 }
 
-/*! \section layers-menu Layers Menu Callback Functions */
-
-/*! \section options-menu Options Menu Callback Functions */
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- *  \note
- *  repeat last command doesn't make sense on options either??? (does it?)
- */
-DEFINE_I_CALLBACK(options_text_size)
-{
-  GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-
-  g_return_if_fail (w_current != NULL);
-  text_edit_dialog (w_current);
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
