@@ -1,7 +1,8 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
+ * Copyright (C) 2017-2018 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,7 +134,7 @@ void x_window_create_drawing(GtkWidget *scrolled, GschemToplevel *w_current)
 
   gtk_container_add(GTK_CONTAINER(scrolled), w_current->drawing_area);
 
-  GTK_WIDGET_SET_FLAGS (w_current->drawing_area, GTK_CAN_FOCUS );
+  gtk_widget_set_can_focus (w_current->drawing_area, TRUE);
   gtk_widget_grab_focus (w_current->drawing_area);
   gtk_widget_show (w_current->drawing_area);
 }
@@ -771,7 +772,15 @@ x_window_open_page_impl (GschemToplevel *w_current, const gchar *filename)
          GTK_DIALOG_DESTROY_WITH_PARENT,
          GTK_MESSAGE_ERROR,
          GTK_BUTTONS_CLOSE,
-         _("<b>An error occurred while loading the requested file.</b>\n\nLoading from '%1$s' failed: %2$s. The gschem log may contain more information."),
+         _("<b>An error occurred while loading the requested file.</b>"
+           "\n\n"
+           "Loading from '%1$s' failed. Error message:"
+           "\n\n"
+           "%2$s."
+           "\n\n"
+           "The lepton-schematic log may contain more information.\n"
+           "You may also launch lepton-schematic with --verbose command"
+           " line switch and monitor program's output in terminal window."),
          fn, err->message);
       gtk_window_set_title (GTK_WINDOW (dialog), _("Failed to load file"));
       gtk_dialog_run (GTK_DIALOG (dialog));
